@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2010, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -156,7 +156,9 @@ public abstract class Toolkit {
         // Finally load VS 2017 DLLs in the following order
         "vcruntime140",
         "vcruntime140_1",
-        "msvcp140"
+        "msvcp140",
+        "msvcp140_1",
+        "msvcp140_2"
 };
 
     private static String lookupToolkitClass(String name) {
